#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 typst
version:              0.6.1
visibility:           public
id:                   typst-0.6.1-7tqkQ139CuuItpLXJdK7wb
key:                  typst-0.6.1-7tqkQ139CuuItpLXJdK7wb
license:              BSD-3-Clause
copyright:            Copyright 2023 John MacFarlane
maintainer:           jgm@berkeley.edu
author:               John MacFarlane
synopsis:             Parsing and evaluating typst syntax.
description:
    A library for parsing and evaluating typst syntax.
    Typst (<https://typst.app>) is a document layout and
    formatting language. This library targets typst 0.10
    and currently offers only partial support.

category:             Text
abi:                  c9ae028e844dc2fe33414efa7161db9b
exposed:              True
exposed-modules:
    Typst Typst.Evaluate Typst.Methods Typst.Parse Typst.Syntax
    Typst.Types Typst.Util

hidden-modules:
    Paths_typst Typst.Bind Typst.Regex Typst.Show Typst.Module.Standard
    Typst.Module.Math Typst.Module.Calc Typst.MathClass

import-dirs:          /usr/lib/ghc-9.6.6/site-local/typst-0.6.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/typst-0.6.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/typst-0.6.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-typst
hs-libraries:         HStypst-0.6.1-7tqkQ139CuuItpLXJdK7wb
depends:
    aeson-2.2.2.0-3wIqYzgVLxh1lGuh6CHfOQ array-0.5.6.0 base-4.18.2.1
    bytestring-0.11.5.3 cassava-0.5.4.1-FxFq9Bi3bC5Dg8h7id3DwD
    containers-0.6.7 directory-1.3.8.5 filepath-1.4.300.1 mtl-2.3.1
    ordered-containers-0.2.4-9KN9Tq9vCaDDpyTw8p0cRR parsec-3.1.16.1
    pretty-1.1.3.6 regex-tdfa-1.3.2.5-EMaUzDKttstEI5BfFz11ci
    scientific-0.3.8.1-9XG2AQ4sh0vL0ppOZ1hCCJ text-2.0.2 time-1.12.2
    toml-parser-2.0.2.0-45IFx2pw5pB5lxPcXOjYWt
    typst-symbols-0.1.7-AjhZZO0iKGoK0FngponDWl
    vector-0.13.2.0-5aTe1V6fRGRBDLXlEcUVda
    xml-conduit-1.9.1.4-5NcvZLRcSVv2Y8J8pEe1P7
    yaml-0.11.11.2-8HrE9BZwyCuLoQBcL7W46u

haddock-interfaces:   /usr/share/doc/haskell-typst/html/typst.haddock
haddock-html:         /usr/share/doc/haskell-typst/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

